Opens an RStudio directory selection dialog and searches the selected directory and its subdirectories for the veraPDF executable. This is helpful when veraPDF is installed, but 'eatArchive' fails to find it.
Opens an RStudio directory selection dialog and searches the selected directory and its subdirectories for the veraPDF executable. This is helpful when veraPDF is installed, but 'eatArchive' fails to find it.